/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ;
typedef struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ;
typedef struct tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg;
typedef struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA;
typedef struct tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA;
typedef struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA;
typedef struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw;
typedef struct tySequence__mIo9bZUsotCEUUtEGNhYmaA tySequence__mIo9bZUsotCEUUtEGNhYmaA;
typedef struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw tyObject_Table__9cHFtxtpgztIcDsypRz9byKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ tySequence__8rKxBHaz7QqNR9a4WIZqqqQ;
typedef struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KLItBKQec3LJzPmfiYYfQA tySequence__KLItBKQec3LJzPmfiYYfQA;
typedef struct tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg;
typedef struct tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg;
typedef struct tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw;
typedef struct tyObject_TBaseLexer__nATxPlDiRTsKxaL2wN88sQ tyObject_TBaseLexer__nATxPlDiRTsKxaL2wN88sQ;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg;
typedef struct tyObject_Token__TUeI5CB5zbppKJkmeKoDMw tyObject_Token__TUeI5CB5zbppKJkmeKoDMw;
typedef struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg;
typedef struct tySequence__shxop0zPIs5Ec3k71aCLuQ tySequence__shxop0zPIs5Ec3k71aCLuQ;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w;
typedef struct tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_TBackend__zoooocqvga73vZuhGAAy6A;
typedef NU8 tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ;
typedef NU8 tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw;
struct tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA {
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ targetCPU;
tyEnum_TSystemCPU__bwO2H8lhMFycb5BeZf6MFQ hostCPU;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw targetOS;
tyEnum_TSystemOS__Vz6QOcCh9a6xfgXqmx3OBpw hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ;
typedef NU64 tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
struct tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ;
struct tyObject_Table__9cHFtxtpgztIcDsypRz9byKw {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__AR9blT7YaZzdImck9a5cntbQ errorOutputs;
tySequence__mIo9bZUsotCEUUtEGNhYmaA* msgContext;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastError;
tyObject_Table__9cHFtxtpgztIcDsypRz9byKw filenameToIndexTbl;
tySequence__8rKxBHaz7QqNR9a4WIZqqqQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w;
typedef NU8 tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg;
typedef NU8 tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w;
typedef NU8 tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q;
typedef NU8 tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg;
struct tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU32 tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw;
typedef NU8 tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g;
typedef NU8 tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg;
typedef NU8 tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ;
typedef NU8 tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA[12];
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
NI Field0;
NI Field1;
NI Field2;
};
typedef NU8 tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___VUPO9alfTq2Ar9a7ZtY9cSPDg* result, void* ClE_0);
void* ClE_0;
} tyProc__Ox1WDSaSyO73VnvAC2a4UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, NimStringDesc* msg, tyEnum_Severity__ai6Qt9bTOrsyOxOrlIkRHUg severity, void* ClE_0);
void* ClE_0;
} tyProc__2bM7rNPFiQD9bOvwFI49bKLQ;
struct tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ {
tyEnum_TBackend__zoooocqvga73vZuhGAAy6A backend;
tyObject_Target__tpQT7iEuCtUPNwog9cc3VgA target;
NI linesCompiled;
tySet_tyEnum_TOption__HPX9bEWraE8wyYLoP9bHbKYQ options;
tySet_tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg globalOptions;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* macrosToExpand;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* arcToExpand;
tyObject_MsgConfig__whxq1VkHUSUyso71rqeLKA m;
tyEnum_FilenameOption__CPbjHbMoELnjs1sUwb4U6w filenameOption;
NimStringDesc* unitSep;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg cmd;
NimStringDesc* cmdInput;
NIM_BOOL projectIsCmd;
NIM_BOOL implicitCmd;
tyEnum_TGCMode__yHeclYqeKaCEfMHNbcWn4w selectedGC;
tyEnum_ExceptionSystem__B9agvczdQhYbOz39atZ7Ap3Q exc;
NIM_BOOL hintProcessingDots;
NI verbosity;
NI numberOfProcessors;
NF lastCmdTime;
tyEnum_SymbolFilesOption__qvBr4umnK8GxeSOSEgbmLg symbolFiles;
NI spellSuggestMax;
tyObject_HashSet__LVIAeIp9cp9c81do0NZpv6Sw cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__T2jOg7rgtA4lKTKRASHfHw features;
tySet_tyEnum_LegacyFeature__YfzcW9bRC8xGYaRkFXliJ2g legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__p9ct5yRAwVUwh1wTpKTgABg ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__DqbWIQj9a2XvtXkztox3VFQ cCompiler;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA modifiedyNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA cmdlineNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA foreignPackageNotes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA notes;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA warningAsErrors;
tySet_tyEnum_TMsgKind__rb52wmU1YxCKdMrEGfD9boA mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
NIM_BOOL isVmTrace;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* configVars;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* symbols;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyTuple__47w2DboNEPf69aPgubZdd7Q nimStdlibVersion;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* dllOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* moduleOverrides;
tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
tySet_tyEnum_StdOrrKind__iRAzj081qUCWECwmGroJoA lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* configFiles;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__KLItBKQec3LJzPmfiYYfQA* toCompile;
tyProc__Ox1WDSaSyO73VnvAC2a4UA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__2bM7rNPFiQD9bOvwFI49bKLQ structuredErrorHook;
NimStringDesc* cppCustomNamespace;
NimStringDesc* nimMainPrefix;
tyObject_ProfileDatacolonObjectType___EiZfxxvPWlUmMsSkx8Qffg* vmProfileData;
NIM_BOOL expandProgress;
NI expandLevels;
NimStringDesc* expandNodeResult;
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw expandPosition;
};
typedef NU8 tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg;
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TBaseLexer__nATxPlDiRTsKxaL2wN88sQ {
  RootObj Sup;
NI bufpos;
NCSTRING buf;
NimStringDesc* bufStorage;
NI bufLen;
tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* stream;
NI lineNumber;
NI sentinel;
NI lineStart;
NI offsetBase;
};
typedef NU8 tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, void* ClE_0);
void* ClE_0;
} tyProc__9aGJhSmkuel6SMfp4pTpyXA;
struct tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw {
  tyObject_TBaseLexer__nATxPlDiRTsKxaL2wN88sQ Sup;
NI32 fileIdx;
NI indentAhead;
NI currLineIndent;
NIM_BOOL strongSpaces;
NIM_BOOL allowTabs;
tyProc__9aGJhSmkuel6SMfp4pTpyXA errorHandler;
tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache;
tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
typedef NU8 tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw;
typedef NU8 tyEnum_NumericalBase__TH9auiUrNz9bAsj4cpFtJS5Q;
struct tyObject_Token__TUeI5CB5zbppKJkmeKoDMw {
tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw tokType;
NI indent;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* ident;
NI64 iNumber;
NF fNumber;
tyEnum_NumericalBase__TH9auiUrNz9bAsj4cpFtJS5Q base;
NI8 strongSpaceA;
NI8 strongSpaceB;
NimStringDesc* literal;
NI line;
NI col;
};
typedef NU8 tyEnum_TLLStreamKind__ChicJ77mD7SkMUxz402udA;
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* s, void* buf, NI bufLen, void* ClE_0);
void* ClE_0;
} tyProc__M3d9crIwWf7vcamB5Yms8GQ;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__HzVCwACFYM9cx9aV62PdjtuA;
struct tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg {
  RootObj Sup;
tyEnum_TLLStreamKind__ChicJ77mD7SkMUxz402udA kind;
FILE* f;
NimStringDesc* s;
NI rd;
NI wr;
NI lineOffset;
tyProc__M3d9crIwWf7vcamB5Yms8GQ repl;
tyProc__HzVCwACFYM9cx9aV62PdjtuA onPrompt;
};
typedef NU8 tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w;
struct tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg {
NI id;
NimStringDesc* s;
tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* next;
NI h;
};
typedef NU16 tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw;
typedef NU8 tyEnum_TJumpDest__jXIgmKyKLvzw26gMgT9c9bIA;
typedef NU8 tySet_tyEnum_MsgFlag__20vXBZGIzyW7fngd9aGsclQ;
typedef NU8 tySet_tyEnum_FormatFlag__twRMOL2LpNvl9aEjgVDqNrg;
typedef NU8 tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w;
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
struct tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ {
tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedName;
tyObject_RopeObj__vUl1aIPQxBiroOuyvqu9bZQ* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA;
struct tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__S5Qo9byZG8QnIQnJQ0ZDWrA flags;
NimStringDesc* customArgs;
};
struct tySequence__shxop0zPIs5Ec3k71aCLuQ {
  TGenericSeq Sup;
  NIM_BOOL data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__mIo9bZUsotCEUUtEGNhYmaA {
  TGenericSeq Sup;
  tyTuple__U3hs4iGgBd4Y9beL6zJV9boQ data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__8rKxBHaz7QqNR9a4WIZqqqQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__2PBRRPxvvEH2sQ9cRi19bh7w data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__KLItBKQec3LJzPmfiYYfQA {
  TGenericSeq Sup;
  tyObject_Cfile__n9b2nVKiXbLpHsfkan9c3Rkw data[SEQ_DECL_SIZE];
};
N_LIB_PRIVATE N_NIMCALL(void, setDefaultLibpath__options_4102)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getSystemConfigPath__nimconf_262)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getPrefixDir__options_4096)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, slash___pathutils_90)(NimStringDesc* base, NimStringDesc* f);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, slash___pathutils_112)(NimStringDesc* base, NimStringDesc* f);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileExists)(NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, readConfigFile__nimconf_226)(NimStringDesc* filename, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*, llStreamOpen__llstream_69)(NimStringDesc* filename, tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w mode);
N_LIB_PRIVATE N_NIMCALL(void, initToken__lexer_248)(tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* L);
N_LIB_PRIVATE N_NIMCALL(void, openLexer__lexer_298)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* lex, NimStringDesc* filename, tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* inputstream, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(void, confTok__nimconf_185)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tySequence__shxop0zPIs5Ec3k71aCLuQ** condStack);
N_LIB_PRIVATE N_NIMCALL(void, ppGetTok__nimconf_15)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok);
N_LIB_PRIVATE N_NIMCALL(void, rawGetTok__lexer_1590)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok);
static N_INLINE(NIM_BOOL, eqeq___idents_229)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* a, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* b);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(void, parseDirective__nimconf_165)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tySequence__shxop0zPIs5Ec3k71aCLuQ** condStack);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw, whichKeyword__idents_223)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* id);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, setLengthSeqV2)(TGenericSeq* s, TNimType* typ, NI newLen);
static N_NIMCALL(void, Marker_tySequence__shxop0zPIs5Ec3k71aCLuQ)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, evalppIf__nimconf_63)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, parseExpr__nimconf_22)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, parseAndExpr__nimconf_43)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, parseAtom__nimconf_26)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config);
N_LIB_PRIVATE N_NIMCALL(void, lexMessage__lexer_327)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_2292)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* symbol);
N_LIB_PRIVATE N_NIMCALL(void, jumpToDirective__nimconf_101)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tyEnum_TJumpDest__jXIgmKyKLvzw26gMgT9c9bIA dest, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tySequence__shxop0zPIs5Ec3k71aCLuQ** condStack);
N_LIB_PRIVATE N_NIMCALL(void, doElse__nimconf_107)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tySequence__shxop0zPIs5Ec3k71aCLuQ** condStack);
N_LIB_PRIVATE N_NIMCALL(void, doElif__nimconf_122)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tySequence__shxop0zPIs5Ec3k71aCLuQ** condStack);
N_LIB_PRIVATE N_NIMCALL(void, doEnd__nimconf_72)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tySequence__shxop0zPIs5Ec3k71aCLuQ** condStack);
N_LIB_PRIVATE N_NIMCALL(void, msgWriteln__msgs_657)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* s, tySet_tyEnum_MsgFlag__20vXBZGIzyW7fngd9aGsclQ flags);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nstFormat)(NimStringDesc* f, tyObject_StringTableObj__9aYeizX9bryvlooxqmPkPxqA* t, tySet_tyEnum_FormatFlag__twRMOL2LpNvl9aEjgVDqNrg flags);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___lexer_230)(tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuNormalize)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(void, putEnv__pureZos_426)(NimStringDesc* key, NimStringDesc* val);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getEnv__pureZos_418)(NimStringDesc* key, NimStringDesc* default_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatSingleElem)(NimStringDesc* formatstr, NimStringDesc* a);
N_LIB_PRIVATE N_NIMCALL(void, parseAssignment__nimconf_197)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tySequence__shxop0zPIs5Ec3k71aCLuQ** condStack);
static N_INLINE(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw, getLineInfo__lexer_192)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw, newLineInfo__msgs_391)(NI32 fileInfoIdx, NI line, NI col);
N_LIB_PRIVATE N_NIMCALL(void, checkSymbol__nimconf_190)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(void, processSwitch__commands_880)(NimStringDesc* switch_0, NimStringDesc* arg, tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w pass, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf);
N_LIB_PRIVATE N_NIMCALL(void, closeLexer__lexer_304)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* lex);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5267)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___nimconf_290)(NimStringDesc* x, NimStringDesc* y);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*, llStreamOpen__llstream_63)(FILE* f);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*, llStreamOpen__llstream_30)(NimStringDesc* data);
N_LIB_PRIVATE N_NIMCALL(void, runNimScript__scriptconfig_188)(tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, NimStringDesc* scriptName, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen, NIM_BOOL freshDefines, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* stream);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getUserConfigPath__nimconf_259)(NimStringDesc* filename);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosgetConfigDir)(void);
static N_INLINE(NIM_BOOL, isEmpty__pathutils_94)(NimStringDesc* x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosgetCurrentDir)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosisRootDir)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nosparentDir)(NimStringDesc* path);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, substr__system_7745)(NimStringDesc* s, NI first, NI last);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, noschangeFileExt)(NimStringDesc* filename, NimStringDesc* ext);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___nimconf_430)(NimStringDesc* x, NimStringDesc* y);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_1128)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info, tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ msg, NimStringDesc* arg, tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_2, "config", 6);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_3, "etc/nim", 7);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_4, "/etc/nim", 8);
extern TNimType NTIlexer__D0giBxIIh38MSXTZOJp8yw_;
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_5, "@", 1);
extern TNimType NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_;
N_LIB_PRIVATE TNimType NTIseqLboolT__shxop0zPIs5Ec3k71aCLuQ_;
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_6, "expected closing \')\'", 20);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_7, "expected \':\'", 12);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_8, "expected @if", 12);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_9, "expected @end", 13);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_10, "putenv", 6);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_11, "prependenv", 10);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_12, "appendenv", 9);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_13, "invalid directive: \'$1\'", 23);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_14, "-", 1);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_15, "--", 2);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_16, "expected identifier, but got: ", 30);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_17, "expected closing \']\'", 20);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_18, "%=", 2);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_19, "&", 1);
extern TNimType NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_;
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_20, "nim.cfg", 7);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_21, "config.nims", 11);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_22, "nim", 3);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_23, "nimcfg", 6);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_24, "nim.cfg", 7);
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_25, "nims", 4);
extern NIM_CONST tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw unknownLineInfo__lineinfos_284;
STRING_LITERAL(TM__fOa3jIA3WjH3i5KrG7HeEg_27, "/home/runner/work/nightlies/nightlies/nim/compiler/nimconf.nim", 62);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__fOa3jIA3WjH3i5KrG7HeEg_26 = {((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_27),
((NI) 297),
((NI) 16)}
;
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5220;
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getSystemConfigPath__nimconf_262)(tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, NimStringDesc* filename) {
	NimStringDesc* result;
	NimStringDesc* p;
	NimStringDesc* T1_;
	result = NIM_NIL;
	p = getPrefixDir__options_4096(conf);
	T1_ = NIM_NIL;
	T1_ = slash___pathutils_112(p, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_2));
	result = slash___pathutils_90(T1_, filename);
	{
		NIM_BOOL T4_;
		NimStringDesc* T7_;
		T4_ = (NIM_BOOL)0;
		T4_ = nosfileExists(result);
		if (!!(T4_)) goto LA5_;
		T7_ = NIM_NIL;
		T7_ = slash___pathutils_112(p, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_3));
		result = slash___pathutils_90(T7_, filename);
	}
	LA5_: ;
	{
		NIM_BOOL T10_;
		T10_ = (NIM_BOOL)0;
		T10_ = nosfileExists(result);
		if (!!(T10_)) goto LA11_;
		result = slash___pathutils_90(((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_4), filename);
	}
	LA11_: ;
	return result;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
N_LIB_PRIVATE N_NIMCALL(void, ppGetTok__nimconf_15)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok) {
	rawGetTok__lexer_1590(L, tok);
	{
		while (1) {
			if (!((*tok).tokType == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 111))) goto LA2;
			rawGetTok__lexer_1590(L, tok);
		} LA2: ;
	}
}
static N_INLINE(NIM_BOOL, eqeq___idents_229)(tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* a, tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg* b) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (a == 0);
		if (T3_) goto LA4_;
		T3_ = (b == 0);
		LA4_: ;
		if (!T3_) goto LA5_;
		result = (a == b);
	}
	goto LA1_;
	LA5_: ;
	{
		result = ((*a).id == (*b).id);
	}
	LA1_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_NIMCALL(void, Marker_tySequence__shxop0zPIs5Ec3k71aCLuQ)(void* p, NI op) {
	tySequence__shxop0zPIs5Ec3k71aCLuQ* a;
	NI T1_;
	a = (tySequence__shxop0zPIs5Ec3k71aCLuQ*)p;
	T1_ = (NI)0;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, parseAtom__nimconf_26)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		if (!((*tok).tokType == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 90))) goto LA3_;
		ppGetTok__nimconf_15(L, tok);
		result = parseExpr__nimconf_22(L, tok, config);
		{
			if (!((*tok).tokType == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 91))) goto LA7_;
			ppGetTok__nimconf_15(L, tok);
		}
		goto LA5_;
		LA7_: ;
		{
			lexMessage__lexer_327((&(*L)), ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_6));
		}
		LA5_: ;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T13_;
		if (!((*tok).tokType == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 45))) goto LA11_;
		ppGetTok__nimconf_15(L, tok);
		T13_ = (NIM_BOOL)0;
		T13_ = parseAtom__nimconf_26(L, tok, config);
		result = !(T13_);
	}
	goto LA1_;
	LA11_: ;
	{
		result = isDefined__options_2292(config, (*(*tok).ident).s);
		ppGetTok__nimconf_15(L, tok);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, parseAndExpr__nimconf_43)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = parseAtom__nimconf_26(L, tok, config);
	{
		while (1) {
			NIM_BOOL b;
			NIM_BOOL T3_;
			if (!((*tok).tokType == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 4))) goto LA2;
			ppGetTok__nimconf_15(L, tok);
			b = parseAtom__nimconf_26(L, tok, config);
			T3_ = (NIM_BOOL)0;
			T3_ = result;
			if (!(T3_)) goto LA4_;
			T3_ = b;
			LA4_: ;
			result = T3_;
		} LA2: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, parseExpr__nimconf_22)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = parseAndExpr__nimconf_43(L, tok, config);
	{
		while (1) {
			NIM_BOOL b;
			NIM_BOOL T3_;
			if (!((*tok).tokType == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 49))) goto LA2;
			ppGetTok__nimconf_15(L, tok);
			b = parseAndExpr__nimconf_43(L, tok, config);
			T3_ = (NIM_BOOL)0;
			T3_ = result;
			if (T3_) goto LA4_;
			T3_ = b;
			LA4_: ;
			result = T3_;
		} LA2: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, evalppIf__nimconf_63)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	ppGetTok__nimconf_15(L, tok);
	result = parseExpr__nimconf_22(L, tok, config);
	{
		if (!((*tok).tokType == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 104))) goto LA3_;
		ppGetTok__nimconf_15(L, tok);
	}
	goto LA1_;
	LA3_: ;
	{
		lexMessage__lexer_327((&(*L)), ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_7));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, doElse__nimconf_107)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tySequence__shxop0zPIs5Ec3k71aCLuQ** condStack) {
	{
		NI T3_;
		T3_ = (((*condStack) ? (*condStack)->Sup.len : 0)-1);
		if (!(T3_ < ((NI) 0))) goto LA4_;
		lexMessage__lexer_327((&(*L)), ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_8));
	}
	LA4_: ;
	ppGetTok__nimconf_15(L, tok);
	{
		if (!((*tok).tokType == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 104))) goto LA8_;
		ppGetTok__nimconf_15(L, tok);
	}
	LA8_: ;
	{
		NI T12_;
		T12_ = (((*condStack) ? (*condStack)->Sup.len : 0)-1);
		if (!(*condStack)->data[T12_]) goto LA13_;
		jumpToDirective__nimconf_101(L, tok, ((tyEnum_TJumpDest__jXIgmKyKLvzw26gMgT9c9bIA) 0), config, condStack);
	}
	LA13_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, doElif__nimconf_122)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tySequence__shxop0zPIs5Ec3k71aCLuQ** condStack) {
	NIM_BOOL res;
	{
		NI T3_;
		T3_ = (((*condStack) ? (*condStack)->Sup.len : 0)-1);
		if (!(T3_ < ((NI) 0))) goto LA4_;
		lexMessage__lexer_327((&(*L)), ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_8));
	}
	LA4_: ;
	res = evalppIf__nimconf_63(L, tok, config);
	{
		NIM_BOOL T8_;
		NI T9_;
		T8_ = (NIM_BOOL)0;
		T9_ = (((*condStack) ? (*condStack)->Sup.len : 0)-1);
		T8_ = (*condStack)->data[T9_];
		if (T8_) goto LA10_;
		T8_ = !(res);
		LA10_: ;
		if (!T8_) goto LA11_;
		jumpToDirective__nimconf_101(L, tok, ((tyEnum_TJumpDest__jXIgmKyKLvzw26gMgT9c9bIA) 1), config, condStack);
	}
	goto LA6_;
	LA11_: ;
	{
		NI T14_;
		T14_ = (((*condStack) ? (*condStack)->Sup.len : 0)-1);
		(*condStack)->data[T14_] = NIM_TRUE;
	}
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, doEnd__nimconf_72)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tySequence__shxop0zPIs5Ec3k71aCLuQ** condStack) {
	NI T6_;
	{
		NI T3_;
		T3_ = (((*condStack) ? (*condStack)->Sup.len : 0)-1);
		if (!(T3_ < ((NI) 0))) goto LA4_;
		lexMessage__lexer_327((&(*L)), ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_8));
	}
	LA4_: ;
	ppGetTok__nimconf_15(L, tok);
	T6_ = (((*condStack) ? (*condStack)->Sup.len : 0)-1);
	unsureAsgnRef((void**) (&(*condStack)), (tySequence__shxop0zPIs5Ec3k71aCLuQ*) setLengthSeqV2(((*condStack))?&((*condStack))->Sup:NIM_NIL, (&NTIseqLboolT__shxop0zPIs5Ec3k71aCLuQ_), ((NI) (T6_))));
}
N_LIB_PRIVATE N_NIMCALL(void, jumpToDirective__nimconf_101)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tyEnum_TJumpDest__jXIgmKyKLvzw26gMgT9c9bIA dest, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tySequence__shxop0zPIs5Ec3k71aCLuQ** condStack) {
	NI nestedIfs;
	nestedIfs = ((NI) 0);
	{
		while (1) {
			{
				NIM_BOOL T5_;
				NIM_BOOL T6_;
				tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw T10_;
				T5_ = (NIM_BOOL)0;
				T6_ = (NIM_BOOL)0;
				T6_ = eqeq___idents_229((*tok).ident, ((tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*) NIM_NIL));
				T5_ = !(T6_);
				if (!(T5_)) goto LA7_;
				T5_ = eqStrings((*(*tok).ident).s, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_5));
				LA7_: ;
				if (!T5_) goto LA8_;
				ppGetTok__nimconf_15(L, tok);
				T10_ = (tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw)0;
				T10_ = whichKeyword__idents_223((*tok).ident);
				switch (T10_) {
				case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 29):
				{
					nestedIfs += ((NI) 1);
				}
				break;
				case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 20):
				{
					{
						NIM_BOOL T15_;
						T15_ = (NIM_BOOL)0;
						T15_ = (dest == ((tyEnum_TJumpDest__jXIgmKyKLvzw26gMgT9c9bIA) 1));
						if (!(T15_)) goto LA16_;
						T15_ = (nestedIfs == ((NI) 0));
						LA16_: ;
						if (!T15_) goto LA17_;
						doElse__nimconf_107(L, tok, config, condStack);
						goto LA1;
					}
					LA17_: ;
				}
				break;
				case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 19):
				{
					{
						NIM_BOOL T22_;
						T22_ = (NIM_BOOL)0;
						T22_ = (dest == ((tyEnum_TJumpDest__jXIgmKyKLvzw26gMgT9c9bIA) 1));
						if (!(T22_)) goto LA23_;
						T22_ = (nestedIfs == ((NI) 0));
						LA23_: ;
						if (!T22_) goto LA24_;
						doElif__nimconf_122(L, tok, config, condStack);
						goto LA1;
					}
					LA24_: ;
				}
				break;
				case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 21):
				{
					{
						if (!(nestedIfs == ((NI) 0))) goto LA29_;
						doEnd__nimconf_72(L, tok, condStack);
						goto LA1;
					}
					LA29_: ;
					{
						if (!(((NI) 0) < nestedIfs)) goto LA33_;
						nestedIfs -= ((NI) 1);
					}
					LA33_: ;
				}
				break;
				default:
				{
				}
				break;
				}
				ppGetTok__nimconf_15(L, tok);
			}
			goto LA3_;
			LA8_: ;
			{
				if (!((*tok).tokType == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 1))) goto LA37_;
				lexMessage__lexer_327((&(*L)), ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_9));
			}
			goto LA3_;
			LA37_: ;
			{
				ppGetTok__nimconf_15(L, tok);
			}
			LA3_: ;
		}
	} LA1: ;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, parseDirective__nimconf_165)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tySequence__shxop0zPIs5Ec3k71aCLuQ** condStack) {
	tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw T1_;
	ppGetTok__nimconf_15(L, tok);
	T1_ = (tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw)0;
	T1_ = whichKeyword__idents_223((*tok).ident);
	switch (T1_) {
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 29):
	{
		NI T3_;
		NIM_BOOL res;
		NI T4_;
		T3_ = ((*condStack) ? (*condStack)->Sup.len : 0);
		unsureAsgnRef((void**) (&(*condStack)), (tySequence__shxop0zPIs5Ec3k71aCLuQ*) setLengthSeqV2(((*condStack))?&((*condStack))->Sup:NIM_NIL, (&NTIseqLboolT__shxop0zPIs5Ec3k71aCLuQ_), ((NI) ((NI)(T3_ + ((NI) 1))))));
		res = evalppIf__nimconf_63(L, tok, config);
		T4_ = (((*condStack) ? (*condStack)->Sup.len : 0)-1);
		(*condStack)->data[T4_] = res;
		{
			if (!!(res)) goto LA7_;
			jumpToDirective__nimconf_101(L, tok, ((tyEnum_TJumpDest__jXIgmKyKLvzw26gMgT9c9bIA) 1), config, condStack);
		}
		LA7_: ;
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 19):
	{
		doElif__nimconf_122(L, tok, config, condStack);
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 20):
	{
		doElse__nimconf_107(L, tok, config, condStack);
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 21):
	{
		doEnd__nimconf_72(L, tok, condStack);
	}
	break;
	case ((tyEnum_TSpecialWord__N2XsqTpO5IzOf2KmXwk4Dw) 209):
	{
		NimStringDesc* T13_;
		NimStringDesc* T14_;
		ppGetTok__nimconf_15(L, tok);
		T13_ = NIM_NIL;
		T13_ = dollar___lexer_230((&(*tok)));
		T14_ = NIM_NIL;
		T14_ = nstFormat(T13_, (*config).configVars, 5);
		msgWriteln__msgs_657(config, T14_, 0);
		ppGetTok__nimconf_15(L, tok);
	}
	break;
	default:
	{
		NimStringDesc* T16_;
		T16_ = NIM_NIL;
		T16_ = nsuNormalize((*(*tok).ident).s);
		if (eqStrings(T16_, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_10))) goto LA17_;
		if (eqStrings(T16_, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_11))) goto LA18_;
		if (eqStrings(T16_, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_12))) goto LA19_;
		goto LA20_;
		LA17_: ;
		{
			NimStringDesc* key;
			NimStringDesc* T23_;
			ppGetTok__nimconf_15(L, tok);
			key = dollar___lexer_230((&(*tok)));
			ppGetTok__nimconf_15(L, tok);
			T23_ = NIM_NIL;
			T23_ = dollar___lexer_230((&(*tok)));
			putEnv__pureZos_426(key, T23_);
			ppGetTok__nimconf_15(L, tok);
		}
		goto LA21_;
		LA18_: ;
		{
			NimStringDesc* key_2;
			NimStringDesc* T25_;
			NimStringDesc* T26_;
			NimStringDesc* T27_;
			ppGetTok__nimconf_15(L, tok);
			key_2 = dollar___lexer_230((&(*tok)));
			ppGetTok__nimconf_15(L, tok);
			T25_ = NIM_NIL;
			T26_ = NIM_NIL;
			T26_ = dollar___lexer_230((&(*tok)));
			T27_ = NIM_NIL;
			T27_ = getEnv__pureZos_418(key_2, ((NimStringDesc*) NIM_NIL));
			T25_ = rawNewString((T26_ ? T26_->Sup.len : 0) + (T27_ ? T27_->Sup.len : 0) + 0);
appendString(T25_, T26_);
appendString(T25_, T27_);
			putEnv__pureZos_426(key_2, T25_);
			ppGetTok__nimconf_15(L, tok);
		}
		goto LA21_;
		LA19_: ;
		{
			NimStringDesc* key_3;
			NimStringDesc* T29_;
			NimStringDesc* T30_;
			NimStringDesc* T31_;
			ppGetTok__nimconf_15(L, tok);
			key_3 = dollar___lexer_230((&(*tok)));
			ppGetTok__nimconf_15(L, tok);
			T29_ = NIM_NIL;
			T30_ = NIM_NIL;
			T30_ = getEnv__pureZos_418(key_3, ((NimStringDesc*) NIM_NIL));
			T31_ = NIM_NIL;
			T31_ = dollar___lexer_230((&(*tok)));
			T29_ = rawNewString((T30_ ? T30_->Sup.len : 0) + (T31_ ? T31_->Sup.len : 0) + 0);
appendString(T29_, T30_);
appendString(T29_, T31_);
			putEnv__pureZos_426(key_3, T29_);
			ppGetTok__nimconf_15(L, tok);
		}
		goto LA21_;
		LA20_: ;
		{
			NimStringDesc* T33_;
			NimStringDesc* T34_;
			T33_ = NIM_NIL;
			T33_ = dollar___lexer_230((&(*tok)));
			T34_ = NIM_NIL;
			T34_ = nsuFormatSingleElem(((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_13), T33_);
			lexMessage__lexer_327((&(*L)), ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T34_);
		}
		LA21_: ;
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, confTok__nimconf_185)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tySequence__shxop0zPIs5Ec3k71aCLuQ** condStack) {
	ppGetTok__nimconf_15(L, tok);
	{
		while (1) {
			NIM_BOOL T3_;
			NIM_BOOL T4_;
			T3_ = (NIM_BOOL)0;
			T4_ = (NIM_BOOL)0;
			T4_ = eqeq___idents_229((*tok).ident, ((tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*) NIM_NIL));
			T3_ = !(T4_);
			if (!(T3_)) goto LA5_;
			T3_ = eqStrings((*(*tok).ident).s, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_5));
			LA5_: ;
			if (!T3_) goto LA2;
			parseDirective__nimconf_165(L, tok, config, condStack);
		} LA2: ;
	}
}
static N_INLINE(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw, getLineInfo__lexer_192)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok) {
	tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw result;
	nimZeroMem((void*)(&result), sizeof(tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw));
	result = newLineInfo__msgs_391((*L).fileIdx, (*tok).line, (*tok).col);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkSymbol__nimconf_190)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok) {
	{
		NimStringDesc* T5_;
		NimStringDesc* T6_;
		if (!!(((*tok).tokType >= ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 2) && (*tok).tokType <= ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 73) || (*tok).tokType >= ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 83) && (*tok).tokType <= ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 85)))) goto LA3_;
		T5_ = NIM_NIL;
		T6_ = NIM_NIL;
		T6_ = dollar___lexer_230(tok);
		T5_ = rawNewString((T6_ ? T6_->Sup.len : 0) + 30);
appendString(T5_, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_16));
appendString(T5_, T6_);
		lexMessage__lexer_327(L, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), T5_);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, parseAssignment__nimconf_197)(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw* L, tyObject_Token__TUeI5CB5zbppKJkmeKoDMw* tok, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config, tySequence__shxop0zPIs5Ec3k71aCLuQ** condStack) {
	tyObject_TLineInfo__66OQV9bsmGEfS6hVHBswcPw info;
	NimStringDesc* s;
	NimStringDesc* val;
	NIM_BOOL percent;
	NIM_BOOL T25_;
	NIM_BOOL T26_;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = eqeq___idents_229((*tok).ident, ((tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*) NIM_NIL));
		if (!!(T3_)) goto LA4_;
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = eqStrings((*(*tok).ident).s, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_14));
			if (T8_) goto LA9_;
			T8_ = eqStrings((*(*tok).ident).s, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_15));
			LA9_: ;
			if (!T8_) goto LA10_;
			confTok__nimconf_185(L, tok, config, condStack);
		}
		LA10_: ;
	}
	LA4_: ;
	info = getLineInfo__lexer_192((&(*L)), (&(*tok)));
	checkSymbol__nimconf_190((&(*L)), (&(*tok)));
	s = dollar___lexer_230((&(*tok)));
	confTok__nimconf_185(L, tok, config, condStack);
	val = ((NimStringDesc*) NIM_NIL);
	{
		while (1) {
			NimStringDesc* T14_;
			if (!((*tok).tokType == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 107))) goto LA13;
			s = addChar(s, 46);
			confTok__nimconf_185(L, tok, config, condStack);
			checkSymbol__nimconf_190((&(*L)), (&(*tok)));
			T14_ = NIM_NIL;
			T14_ = dollar___lexer_230((&(*tok)));
			s = resizeString(s, (T14_ ? T14_->Sup.len : 0) + 0);
appendString(s, T14_);
			confTok__nimconf_185(L, tok, config, condStack);
		} LA13: ;
	}
	{
		NimStringDesc* T19_;
		if (!((*tok).tokType == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 92))) goto LA17_;
		confTok__nimconf_185(L, tok, config, condStack);
		checkSymbol__nimconf_190((&(*L)), (&(*tok)));
		val = addChar(val, 91);
		T19_ = NIM_NIL;
		T19_ = dollar___lexer_230((&(*tok)));
		val = resizeString(val, (T19_ ? T19_->Sup.len : 0) + 0);
appendString(val, T19_);
		confTok__nimconf_185(L, tok, config, condStack);
		{
			if (!((*tok).tokType == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 93))) goto LA22_;
			confTok__nimconf_185(L, tok, config, condStack);
		}
		goto LA20_;
		LA22_: ;
		{
			lexMessage__lexer_327((&(*L)), ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_17));
		}
		LA20_: ;
		val = addChar(val, 93);
	}
	LA17_: ;
	T25_ = (NIM_BOOL)0;
	T26_ = (NIM_BOOL)0;
	T26_ = eqeq___idents_229((*tok).ident, ((tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*) NIM_NIL));
	T25_ = !(T26_);
	if (!(T25_)) goto LA27_;
	T25_ = eqStrings((*(*tok).ident).s, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_18));
	LA27_: ;
	percent = T25_;
	{
		NIM_BOOL T30_;
		NimStringDesc* T38_;
		T30_ = (NIM_BOOL)0;
		T30_ = ((*tok).tokType == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 104) || (*tok).tokType == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 106));
		if (T30_) goto LA31_;
		T30_ = percent;
		LA31_: ;
		if (!T30_) goto LA32_;
		{
			if (!(((NI) 0) < (val ? val->Sup.len : 0))) goto LA36_;
			val = addChar(val, 58);
		}
		LA36_: ;
		confTok__nimconf_185(L, tok, config, condStack);
		checkSymbol__nimconf_190((&(*L)), (&(*tok)));
		T38_ = NIM_NIL;
		T38_ = dollar___lexer_230((&(*tok)));
		val = resizeString(val, (T38_ ? T38_->Sup.len : 0) + 0);
appendString(val, T38_);
		confTok__nimconf_185(L, tok, config, condStack);
		{
			NimStringDesc* T43_;
			NimStringDesc* T44_;
			if (!((*tok).tokType == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 104) || (*tok).tokType == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 106))) goto LA41_;
			T43_ = NIM_NIL;
			T43_ = dollar___lexer_230((&(*tok)));
			val = resizeString(val, (T43_ ? T43_->Sup.len : 0) + 0);
appendString(val, T43_);
			confTok__nimconf_185(L, tok, config, condStack);
			checkSymbol__nimconf_190((&(*L)), (&(*tok)));
			T44_ = NIM_NIL;
			T44_ = dollar___lexer_230((&(*tok)));
			val = resizeString(val, (T44_ ? T44_->Sup.len : 0) + 0);
appendString(val, T44_);
			confTok__nimconf_185(L, tok, config, condStack);
		}
		LA41_: ;
		{
			while (1) {
				NIM_BOOL T47_;
				NIM_BOOL T48_;
				NimStringDesc* T50_;
				T47_ = (NIM_BOOL)0;
				T48_ = (NIM_BOOL)0;
				T48_ = eqeq___idents_229((*tok).ident, ((tyObject_TIdent__PKDcQ7dqdhiSW9c9cXUFFpMg*) NIM_NIL));
				T47_ = !(T48_);
				if (!(T47_)) goto LA49_;
				T47_ = eqStrings((*(*tok).ident).s, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_19));
				LA49_: ;
				if (!T47_) goto LA46;
				confTok__nimconf_185(L, tok, config, condStack);
				checkSymbol__nimconf_190((&(*L)), (&(*tok)));
				T50_ = NIM_NIL;
				T50_ = dollar___lexer_230((&(*tok)));
				val = resizeString(val, (T50_ ? T50_->Sup.len : 0) + 0);
appendString(val, T50_);
				confTok__nimconf_185(L, tok, config, condStack);
			} LA46: ;
		}
	}
	LA32_: ;
	{
		NimStringDesc* T55_;
		if (!percent) goto LA53_;
		T55_ = NIM_NIL;
		T55_ = nstFormat(val, (*config).configVars, 3);
		processSwitch__commands_880(s, T55_, ((tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w) 2), info, config);
	}
	goto LA51_;
	LA53_: ;
	{
		processSwitch__commands_880(s, val, ((tyEnum_TCmdLinePass__cBZGGr1dZbGRibY9aQJwM8w) 2), info, config);
	}
	LA51_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, readConfigFile__nimconf_226)(NimStringDesc* filename, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* config) {
	NIM_BOOL result;
	tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw L;
	tyObject_Token__TUeI5CB5zbppKJkmeKoDMw tok;
	tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* stream;
{	result = (NIM_BOOL)0;
	nimZeroMem((void*)(&L), sizeof(tyObject_Lexer__D0giBxIIh38MSXTZOJp8yw));
	L.Sup.Sup.m_type = (&NTIlexer__D0giBxIIh38MSXTZOJp8yw_);
	nimZeroMem((void*)(&tok), sizeof(tyObject_Token__TUeI5CB5zbppKJkmeKoDMw));
	stream = NIM_NIL;
	stream = llStreamOpen__llstream_69(filename, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 0));
	{
		tySequence__shxop0zPIs5Ec3k71aCLuQ* condStack;
		if (!!((stream == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL)))) goto LA3_;
		initToken__lexer_248((&tok));
		openLexer__lexer_298((&L), filename, stream, cache, config);
		tok.tokType = ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 1);
		condStack = NIM_NIL;
		confTok__nimconf_185((&L), (&tok), config, (&condStack));
		{
			while (1) {
				if (!!((tok.tokType == ((tyEnum_TokType__jtO8nsEQZ3q9auoz8Uy0Ohw) 1)))) goto LA6;
				parseAssignment__nimconf_197((&L), (&tok), config, (&condStack));
			} LA6: ;
		}
		{
			NI T9_;
			T9_ = (condStack ? condStack->Sup.len : 0);
			if (!(((NI) 0) < T9_)) goto LA10_;
			lexMessage__lexer_327((&L), ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 15), ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_9));
		}
		LA10_: ;
		closeLexer__lexer_304((&L));
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5311)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5273)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5316)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5267((&gch__system_5220.zct), c);
}
static N_INLINE(void, decRef__system_5318)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5316(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5273(src);
		incRef__system_5311(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5273((*dest));
		decRef__system_5318(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5273(p);
	decRef__system_5318(T1_);
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, getUserConfigPath__nimconf_259)(NimStringDesc* filename) {
	NimStringDesc* result;
	NimStringDesc* T1_;
	NimStringDesc* T2_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = nosgetConfigDir();
	T2_ = NIM_NIL;
	T2_ = slash___pathutils_112(T1_, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_22));
	result = slash___pathutils_90(T2_, filename);
	return result;
}
static N_INLINE(NIM_BOOL, isEmpty__pathutils_94)(NimStringDesc* x) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((x ? x->Sup.len : 0) == ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, loadConfigs__nimconf_267)(NimStringDesc* cfg, tyObject_IdentCachecolonObjectType___ssh0vzVb9aCQuB6ShpimfIQ* cache, tyObject_ConfigRefcolonObjectType___XoIrMAjHi4NOQu4oAkNfVQ* conf, tyObject_IdGeneratorcolonObjectType___WVCsDyf9bR1PcjDFjcjm9bRg* idgen) {
	NimStringDesc* pd;
	NimStringDesc* scriptFile;
	NIM_BOOL scriptIsProj;
	setDefaultLibpath__options_4102(conf);
	{
		NimStringDesc* configPathX60gensym15_;
		if (!!((((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 17))&63U)))!=0))) goto LA3_;
		configPathX60gensym15_ = getSystemConfigPath__nimconf_262(conf, cfg);
		{
			NIM_BOOL T7_;
			NI T10_;
			NimStringDesc* T11_;
			T7_ = (NIM_BOOL)0;
			T7_ = readConfigFile__nimconf_226(configPathX60gensym15_, cache, conf);
			if (!T7_) goto LA8_;
			asgnRef((void**) (&(*conf).configFiles), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).configFiles), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
			T10_ = (*conf).configFiles->Sup.len++;
			T11_ = NIM_NIL;
			T11_ = (*conf).configFiles->data[T10_]; (*conf).configFiles->data[T10_] = copyStringRC1(configPathX60gensym15_);
			if (T11_) nimGCunrefNoCycle(T11_);
		}
		LA8_: ;
		{
			NIM_BOOL T14_;
			NimStringDesc* pX60gensym16_;
			tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* sX60gensym16_;
			T14_ = (NIM_BOOL)0;
			T14_ = eqeq___nimconf_290(cfg, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_20));
			if (!T14_) goto LA15_;
			pX60gensym16_ = getSystemConfigPath__nimconf_262(conf, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_21));
			sX60gensym16_ = NIM_NIL;
			{
				NIM_BOOL T19_;
				T19_ = (NIM_BOOL)0;
				T19_ = NIM_FALSE;
				if (!(T19_)) goto LA20_;
				T19_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 2))&63U)))!=0);
				LA20_: ;
				if (!T19_) goto LA21_;
				{
					if (!(*conf).projectIsStdin) goto LA25_;
					sX60gensym16_ = llStreamOpen__llstream_63(__stdinp);
				}
				goto LA23_;
				LA25_: ;
				{
					if (!(*conf).projectIsCmd) goto LA28_;
					sX60gensym16_ = llStreamOpen__llstream_30((*conf).cmdInput);
				}
				goto LA23_;
				LA28_: ;
				LA23_: ;
			}
			LA21_: ;
			{
				NIM_BOOL T32_;
				T32_ = (NIM_BOOL)0;
				T32_ = (sX60gensym16_ == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL));
				if (!(T32_)) goto LA33_;
				T32_ = nosfileExists(pX60gensym16_);
				LA33_: ;
				if (!T32_) goto LA34_;
				sX60gensym16_ = llStreamOpen__llstream_69(pX60gensym16_, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 0));
			}
			LA34_: ;
			{
				NI T40_;
				NimStringDesc* T41_;
				if (!!((sX60gensym16_ == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL)))) goto LA38_;
				asgnRef((void**) (&(*conf).configFiles), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).configFiles), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
				T40_ = (*conf).configFiles->Sup.len++;
				T41_ = NIM_NIL;
				T41_ = (*conf).configFiles->data[T40_]; (*conf).configFiles->data[T40_] = copyStringRC1(pX60gensym16_);
				if (T41_) nimGCunrefNoCycle(T41_);
				runNimScript__scriptconfig_188(cache, pX60gensym16_, idgen, NIM_FALSE, conf, sX60gensym16_);
			}
			LA38_: ;
		}
		LA15_: ;
	}
	LA3_: ;
	{
		NimStringDesc* configPathX60gensym20_;
		if (!!((((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 19))&63U)))!=0))) goto LA44_;
		configPathX60gensym20_ = getUserConfigPath__nimconf_259(cfg);
		{
			NIM_BOOL T48_;
			NI T51_;
			NimStringDesc* T52_;
			T48_ = (NIM_BOOL)0;
			T48_ = readConfigFile__nimconf_226(configPathX60gensym20_, cache, conf);
			if (!T48_) goto LA49_;
			asgnRef((void**) (&(*conf).configFiles), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).configFiles), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
			T51_ = (*conf).configFiles->Sup.len++;
			T52_ = NIM_NIL;
			T52_ = (*conf).configFiles->data[T51_]; (*conf).configFiles->data[T51_] = copyStringRC1(configPathX60gensym20_);
			if (T52_) nimGCunrefNoCycle(T52_);
		}
		LA49_: ;
		{
			NIM_BOOL T55_;
			NimStringDesc* pX60gensym21_;
			tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* sX60gensym21_;
			T55_ = (NIM_BOOL)0;
			T55_ = eqeq___nimconf_290(cfg, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_20));
			if (!T55_) goto LA56_;
			pX60gensym21_ = getUserConfigPath__nimconf_259(((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_21));
			sX60gensym21_ = NIM_NIL;
			{
				NIM_BOOL T60_;
				T60_ = (NIM_BOOL)0;
				T60_ = NIM_FALSE;
				if (!(T60_)) goto LA61_;
				T60_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 2))&63U)))!=0);
				LA61_: ;
				if (!T60_) goto LA62_;
				{
					if (!(*conf).projectIsStdin) goto LA66_;
					sX60gensym21_ = llStreamOpen__llstream_63(__stdinp);
				}
				goto LA64_;
				LA66_: ;
				{
					if (!(*conf).projectIsCmd) goto LA69_;
					sX60gensym21_ = llStreamOpen__llstream_30((*conf).cmdInput);
				}
				goto LA64_;
				LA69_: ;
				LA64_: ;
			}
			LA62_: ;
			{
				NIM_BOOL T73_;
				T73_ = (NIM_BOOL)0;
				T73_ = (sX60gensym21_ == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL));
				if (!(T73_)) goto LA74_;
				T73_ = nosfileExists(pX60gensym21_);
				LA74_: ;
				if (!T73_) goto LA75_;
				sX60gensym21_ = llStreamOpen__llstream_69(pX60gensym21_, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 0));
			}
			LA75_: ;
			{
				NI T81_;
				NimStringDesc* T82_;
				if (!!((sX60gensym21_ == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL)))) goto LA79_;
				asgnRef((void**) (&(*conf).configFiles), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).configFiles), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
				T81_ = (*conf).configFiles->Sup.len++;
				T82_ = NIM_NIL;
				T82_ = (*conf).configFiles->data[T81_]; (*conf).configFiles->data[T81_] = copyStringRC1(pX60gensym21_);
				if (T82_) nimGCunrefNoCycle(T82_);
				runNimScript__scriptconfig_188(cache, pX60gensym21_, idgen, NIM_FALSE, conf, sX60gensym21_);
			}
			LA79_: ;
		}
		LA56_: ;
	}
	LA44_: ;
	{
		NIM_BOOL T85_;
		T85_ = (NIM_BOOL)0;
		T85_ = isEmpty__pathutils_94((*conf).projectPath);
		if (!!(T85_)) goto LA86_;
		pd = (*conf).projectPath;
	}
	goto LA83_;
	LA86_: ;
	{
		pd = nosgetCurrentDir();
	}
	LA83_: ;
	{
		if (!!((((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 20))&63U)))!=0))) goto LA91_;
		{
			NimStringDesc* dir;
			NimStringDesc* colontmp_;
			dir = NIM_NIL;
			colontmp_ = NIM_NIL;
			colontmp_ = pd;
			{
				NimStringDesc* current;
				if (!NIM_FALSE) goto LA96_;
				current = copyString(colontmp_);
				{
					NimStringDesc* configPathX60gensym25_;
					if (!NIM_FALSE) goto LA100_;
					dir = colontmp_;
					configPathX60gensym25_ = slash___pathutils_90(dir, cfg);
					{
						NIM_BOOL T104_;
						NI T107_;
						NimStringDesc* T108_;
						T104_ = (NIM_BOOL)0;
						T104_ = readConfigFile__nimconf_226(configPathX60gensym25_, cache, conf);
						if (!T104_) goto LA105_;
						asgnRef((void**) (&(*conf).configFiles), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).configFiles), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
						T107_ = (*conf).configFiles->Sup.len++;
						T108_ = NIM_NIL;
						T108_ = (*conf).configFiles->data[T107_]; (*conf).configFiles->data[T107_] = copyStringRC1(configPathX60gensym25_);
						if (T108_) nimGCunrefNoCycle(T108_);
					}
					LA105_: ;
					{
						NIM_BOOL T111_;
						NimStringDesc* pX60gensym26_;
						tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* sX60gensym26_;
						T111_ = (NIM_BOOL)0;
						T111_ = eqeq___nimconf_290(cfg, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_20));
						if (!T111_) goto LA112_;
						pX60gensym26_ = slash___pathutils_90(dir, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_21));
						sX60gensym26_ = NIM_NIL;
						{
							NIM_BOOL T116_;
							T116_ = (NIM_BOOL)0;
							T116_ = NIM_FALSE;
							if (!(T116_)) goto LA117_;
							T116_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 2))&63U)))!=0);
							LA117_: ;
							if (!T116_) goto LA118_;
							{
								if (!(*conf).projectIsStdin) goto LA122_;
								sX60gensym26_ = llStreamOpen__llstream_63(__stdinp);
							}
							goto LA120_;
							LA122_: ;
							{
								if (!(*conf).projectIsCmd) goto LA125_;
								sX60gensym26_ = llStreamOpen__llstream_30((*conf).cmdInput);
							}
							goto LA120_;
							LA125_: ;
							LA120_: ;
						}
						LA118_: ;
						{
							NIM_BOOL T129_;
							T129_ = (NIM_BOOL)0;
							T129_ = (sX60gensym26_ == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL));
							if (!(T129_)) goto LA130_;
							T129_ = nosfileExists(pX60gensym26_);
							LA130_: ;
							if (!T129_) goto LA131_;
							sX60gensym26_ = llStreamOpen__llstream_69(pX60gensym26_, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 0));
						}
						LA131_: ;
						{
							NI T137_;
							NimStringDesc* T138_;
							if (!!((sX60gensym26_ == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL)))) goto LA135_;
							asgnRef((void**) (&(*conf).configFiles), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).configFiles), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
							T137_ = (*conf).configFiles->Sup.len++;
							T138_ = NIM_NIL;
							T138_ = (*conf).configFiles->data[T137_]; (*conf).configFiles->data[T137_] = copyStringRC1(pX60gensym26_);
							if (T138_) nimGCunrefNoCycle(T138_);
							runNimScript__scriptconfig_188(cache, pX60gensym26_, idgen, NIM_FALSE, conf, sX60gensym26_);
						}
						LA135_: ;
					}
					LA112_: ;
				}
				LA100_: ;
				{
					while (1) {
						NimStringDesc* configPathX60gensym25__2;
						{
							NIM_BOOL T143_;
							T143_ = (NIM_BOOL)0;
							T143_ = nosisRootDir(current);
							if (!T143_) goto LA144_;
							goto LA139;
						}
						LA144_: ;
						current = nosparentDir(current);
						dir = current;
						configPathX60gensym25__2 = slash___pathutils_90(dir, cfg);
						{
							NIM_BOOL T148_;
							NI T151_;
							NimStringDesc* T152_;
							T148_ = (NIM_BOOL)0;
							T148_ = readConfigFile__nimconf_226(configPathX60gensym25__2, cache, conf);
							if (!T148_) goto LA149_;
							asgnRef((void**) (&(*conf).configFiles), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).configFiles), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
							T151_ = (*conf).configFiles->Sup.len++;
							T152_ = NIM_NIL;
							T152_ = (*conf).configFiles->data[T151_]; (*conf).configFiles->data[T151_] = copyStringRC1(configPathX60gensym25__2);
							if (T152_) nimGCunrefNoCycle(T152_);
						}
						LA149_: ;
						{
							NIM_BOOL T155_;
							NimStringDesc* pX60gensym26__2;
							tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* sX60gensym26__2;
							T155_ = (NIM_BOOL)0;
							T155_ = eqeq___nimconf_290(cfg, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_20));
							if (!T155_) goto LA156_;
							pX60gensym26__2 = slash___pathutils_90(dir, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_21));
							sX60gensym26__2 = NIM_NIL;
							{
								NIM_BOOL T160_;
								T160_ = (NIM_BOOL)0;
								T160_ = NIM_FALSE;
								if (!(T160_)) goto LA161_;
								T160_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 2))&63U)))!=0);
								LA161_: ;
								if (!T160_) goto LA162_;
								{
									if (!(*conf).projectIsStdin) goto LA166_;
									sX60gensym26__2 = llStreamOpen__llstream_63(__stdinp);
								}
								goto LA164_;
								LA166_: ;
								{
									if (!(*conf).projectIsCmd) goto LA169_;
									sX60gensym26__2 = llStreamOpen__llstream_30((*conf).cmdInput);
								}
								goto LA164_;
								LA169_: ;
								LA164_: ;
							}
							LA162_: ;
							{
								NIM_BOOL T173_;
								T173_ = (NIM_BOOL)0;
								T173_ = (sX60gensym26__2 == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL));
								if (!(T173_)) goto LA174_;
								T173_ = nosfileExists(pX60gensym26__2);
								LA174_: ;
								if (!T173_) goto LA175_;
								sX60gensym26__2 = llStreamOpen__llstream_69(pX60gensym26__2, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 0));
							}
							LA175_: ;
							{
								NI T181_;
								NimStringDesc* T182_;
								if (!!((sX60gensym26__2 == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL)))) goto LA179_;
								asgnRef((void**) (&(*conf).configFiles), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).configFiles), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
								T181_ = (*conf).configFiles->Sup.len++;
								T182_ = NIM_NIL;
								T182_ = (*conf).configFiles->data[T181_]; (*conf).configFiles->data[T181_] = copyStringRC1(pX60gensym26__2);
								if (T182_) nimGCunrefNoCycle(T182_);
								runNimScript__scriptconfig_188(cache, pX60gensym26__2, idgen, NIM_FALSE, conf, sX60gensym26__2);
							}
							LA179_: ;
						}
						LA156_: ;
					}
				} LA139: ;
			}
			goto LA94_;
			LA96_: ;
			{
				{
					NI i;
					NI colontmp__2;
					NI res;
					i = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__2 = (NI)((colontmp_ ? colontmp_->Sup.len : 0) - ((NI) 2));
					res = ((NI) 0);
					{
						while (1) {
							if (!(res <= colontmp__2)) goto LA186;
							i = res;
							{
								NIM_BOOL T189_;
								NIM_BOOL T191_;
								NimStringDesc* configPathX60gensym25__3;
								T189_ = (NIM_BOOL)0;
								T189_ = (((NU8)(colontmp_->data[i])) == ((NU8)(47)) || ((NU8)(colontmp_->data[i])) == ((NU8)(47)));
								if (!(T189_)) goto LA190_;
								T191_ = (NIM_BOOL)0;
								T191_ = (i == ((NI) 0));
								if (T191_) goto LA192_;
								T191_ = !((((NU8)(colontmp_->data[(NI)(i - ((NI) 1))])) == ((NU8)(47)) || ((NU8)(colontmp_->data[(NI)(i - ((NI) 1))])) == ((NU8)(47))));
								LA192_: ;
								T189_ = T191_;
								LA190_: ;
								if (!T189_) goto LA193_;
								dir = substr__system_7745(colontmp_, ((NI) 0), i);
								configPathX60gensym25__3 = slash___pathutils_90(dir, cfg);
								{
									NIM_BOOL T197_;
									NI T200_;
									NimStringDesc* T201_;
									T197_ = (NIM_BOOL)0;
									T197_ = readConfigFile__nimconf_226(configPathX60gensym25__3, cache, conf);
									if (!T197_) goto LA198_;
									asgnRef((void**) (&(*conf).configFiles), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).configFiles), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
									T200_ = (*conf).configFiles->Sup.len++;
									T201_ = NIM_NIL;
									T201_ = (*conf).configFiles->data[T200_]; (*conf).configFiles->data[T200_] = copyStringRC1(configPathX60gensym25__3);
									if (T201_) nimGCunrefNoCycle(T201_);
								}
								LA198_: ;
								{
									NIM_BOOL T204_;
									NimStringDesc* pX60gensym26__3;
									tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* sX60gensym26__3;
									T204_ = (NIM_BOOL)0;
									T204_ = eqeq___nimconf_290(cfg, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_20));
									if (!T204_) goto LA205_;
									pX60gensym26__3 = slash___pathutils_90(dir, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_21));
									sX60gensym26__3 = NIM_NIL;
									{
										NIM_BOOL T209_;
										T209_ = (NIM_BOOL)0;
										T209_ = NIM_FALSE;
										if (!(T209_)) goto LA210_;
										T209_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 2))&63U)))!=0);
										LA210_: ;
										if (!T209_) goto LA211_;
										{
											if (!(*conf).projectIsStdin) goto LA215_;
											sX60gensym26__3 = llStreamOpen__llstream_63(__stdinp);
										}
										goto LA213_;
										LA215_: ;
										{
											if (!(*conf).projectIsCmd) goto LA218_;
											sX60gensym26__3 = llStreamOpen__llstream_30((*conf).cmdInput);
										}
										goto LA213_;
										LA218_: ;
										LA213_: ;
									}
									LA211_: ;
									{
										NIM_BOOL T222_;
										T222_ = (NIM_BOOL)0;
										T222_ = (sX60gensym26__3 == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL));
										if (!(T222_)) goto LA223_;
										T222_ = nosfileExists(pX60gensym26__3);
										LA223_: ;
										if (!T222_) goto LA224_;
										sX60gensym26__3 = llStreamOpen__llstream_69(pX60gensym26__3, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 0));
									}
									LA224_: ;
									{
										NI T230_;
										NimStringDesc* T231_;
										if (!!((sX60gensym26__3 == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL)))) goto LA228_;
										asgnRef((void**) (&(*conf).configFiles), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).configFiles), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
										T230_ = (*conf).configFiles->Sup.len++;
										T231_ = NIM_NIL;
										T231_ = (*conf).configFiles->data[T230_]; (*conf).configFiles->data[T230_] = copyStringRC1(pX60gensym26__3);
										if (T231_) nimGCunrefNoCycle(T231_);
										runNimScript__scriptconfig_188(cache, pX60gensym26__3, idgen, NIM_FALSE, conf, sX60gensym26__3);
									}
									LA228_: ;
								}
								LA205_: ;
							}
							LA193_: ;
							res += ((NI) 1);
						} LA186: ;
					}
				}
				{
					NimStringDesc* configPathX60gensym25__4;
					if (!NIM_FALSE) goto LA234_;
					dir = colontmp_;
					configPathX60gensym25__4 = slash___pathutils_90(dir, cfg);
					{
						NIM_BOOL T238_;
						NI T241_;
						NimStringDesc* T242_;
						T238_ = (NIM_BOOL)0;
						T238_ = readConfigFile__nimconf_226(configPathX60gensym25__4, cache, conf);
						if (!T238_) goto LA239_;
						asgnRef((void**) (&(*conf).configFiles), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).configFiles), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
						T241_ = (*conf).configFiles->Sup.len++;
						T242_ = NIM_NIL;
						T242_ = (*conf).configFiles->data[T241_]; (*conf).configFiles->data[T241_] = copyStringRC1(configPathX60gensym25__4);
						if (T242_) nimGCunrefNoCycle(T242_);
					}
					LA239_: ;
					{
						NIM_BOOL T245_;
						NimStringDesc* pX60gensym26__4;
						tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* sX60gensym26__4;
						T245_ = (NIM_BOOL)0;
						T245_ = eqeq___nimconf_290(cfg, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_20));
						if (!T245_) goto LA246_;
						pX60gensym26__4 = slash___pathutils_90(dir, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_21));
						sX60gensym26__4 = NIM_NIL;
						{
							NIM_BOOL T250_;
							T250_ = (NIM_BOOL)0;
							T250_ = NIM_FALSE;
							if (!(T250_)) goto LA251_;
							T250_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 2))&63U)))!=0);
							LA251_: ;
							if (!T250_) goto LA252_;
							{
								if (!(*conf).projectIsStdin) goto LA256_;
								sX60gensym26__4 = llStreamOpen__llstream_63(__stdinp);
							}
							goto LA254_;
							LA256_: ;
							{
								if (!(*conf).projectIsCmd) goto LA259_;
								sX60gensym26__4 = llStreamOpen__llstream_30((*conf).cmdInput);
							}
							goto LA254_;
							LA259_: ;
							LA254_: ;
						}
						LA252_: ;
						{
							NIM_BOOL T263_;
							T263_ = (NIM_BOOL)0;
							T263_ = (sX60gensym26__4 == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL));
							if (!(T263_)) goto LA264_;
							T263_ = nosfileExists(pX60gensym26__4);
							LA264_: ;
							if (!T263_) goto LA265_;
							sX60gensym26__4 = llStreamOpen__llstream_69(pX60gensym26__4, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 0));
						}
						LA265_: ;
						{
							NI T271_;
							NimStringDesc* T272_;
							if (!!((sX60gensym26__4 == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL)))) goto LA269_;
							asgnRef((void**) (&(*conf).configFiles), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).configFiles), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
							T271_ = (*conf).configFiles->Sup.len++;
							T272_ = NIM_NIL;
							T272_ = (*conf).configFiles->data[T271_]; (*conf).configFiles->data[T271_] = copyStringRC1(pX60gensym26__4);
							if (T272_) nimGCunrefNoCycle(T272_);
							runNimScript__scriptconfig_188(cache, pX60gensym26__4, idgen, NIM_FALSE, conf, sX60gensym26__4);
						}
						LA269_: ;
					}
					LA246_: ;
				}
				LA234_: ;
			}
			LA94_: ;
		}
	}
	LA91_: ;
	{
		NimStringDesc* configPathX60gensym30_;
		if (!!((((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 18))&63U)))!=0))) goto LA275_;
		configPathX60gensym30_ = slash___pathutils_90(pd, cfg);
		{
			NIM_BOOL T279_;
			NI T282_;
			NimStringDesc* T283_;
			T279_ = (NIM_BOOL)0;
			T279_ = readConfigFile__nimconf_226(configPathX60gensym30_, cache, conf);
			if (!T279_) goto LA280_;
			asgnRef((void**) (&(*conf).configFiles), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).configFiles), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
			T282_ = (*conf).configFiles->Sup.len++;
			T283_ = NIM_NIL;
			T283_ = (*conf).configFiles->data[T282_]; (*conf).configFiles->data[T282_] = copyStringRC1(configPathX60gensym30_);
			if (T283_) nimGCunrefNoCycle(T283_);
		}
		LA280_: ;
		{
			NIM_BOOL T286_;
			NimStringDesc* pX60gensym31_;
			tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* sX60gensym31_;
			T286_ = (NIM_BOOL)0;
			T286_ = eqeq___nimconf_290(cfg, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_20));
			if (!T286_) goto LA287_;
			pX60gensym31_ = slash___pathutils_90(pd, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_21));
			sX60gensym31_ = NIM_NIL;
			{
				NIM_BOOL T291_;
				T291_ = (NIM_BOOL)0;
				T291_ = NIM_FALSE;
				if (!(T291_)) goto LA292_;
				T291_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 2))&63U)))!=0);
				LA292_: ;
				if (!T291_) goto LA293_;
				{
					if (!(*conf).projectIsStdin) goto LA297_;
					sX60gensym31_ = llStreamOpen__llstream_63(__stdinp);
				}
				goto LA295_;
				LA297_: ;
				{
					if (!(*conf).projectIsCmd) goto LA300_;
					sX60gensym31_ = llStreamOpen__llstream_30((*conf).cmdInput);
				}
				goto LA295_;
				LA300_: ;
				LA295_: ;
			}
			LA293_: ;
			{
				NIM_BOOL T304_;
				T304_ = (NIM_BOOL)0;
				T304_ = (sX60gensym31_ == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL));
				if (!(T304_)) goto LA305_;
				T304_ = nosfileExists(pX60gensym31_);
				LA305_: ;
				if (!T304_) goto LA306_;
				sX60gensym31_ = llStreamOpen__llstream_69(pX60gensym31_, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 0));
			}
			LA306_: ;
			{
				NI T312_;
				NimStringDesc* T313_;
				if (!!((sX60gensym31_ == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL)))) goto LA310_;
				asgnRef((void**) (&(*conf).configFiles), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).configFiles), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
				T312_ = (*conf).configFiles->Sup.len++;
				T313_ = NIM_NIL;
				T313_ = (*conf).configFiles->data[T312_]; (*conf).configFiles->data[T312_] = copyStringRC1(pX60gensym31_);
				if (T313_) nimGCunrefNoCycle(T313_);
				runNimScript__scriptconfig_188(cache, pX60gensym31_, idgen, NIM_FALSE, conf, sX60gensym31_);
			}
			LA310_: ;
		}
		LA287_: ;
		{
			NimStringDesc* projectConfig;
			NimStringDesc* configPathX60gensym35_;
			if (!!((((*conf).projectName ? (*conf).projectName->Sup.len : 0) == ((NI) 0)))) goto LA316_;
			projectConfig = noschangeFileExt((*conf).projectFull, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_23));
			{
				NIM_BOOL T320_;
				T320_ = (NIM_BOOL)0;
				T320_ = nosfileExists(projectConfig);
				if (!!(T320_)) goto LA321_;
				projectConfig = noschangeFileExt((*conf).projectFull, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_24));
			}
			LA321_: ;
			configPathX60gensym35_ = projectConfig;
			{
				NIM_BOOL T325_;
				NI T328_;
				NimStringDesc* T329_;
				T325_ = (NIM_BOOL)0;
				T325_ = readConfigFile__nimconf_226(configPathX60gensym35_, cache, conf);
				if (!T325_) goto LA326_;
				asgnRef((void**) (&(*conf).configFiles), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).configFiles), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
				T328_ = (*conf).configFiles->Sup.len++;
				T329_ = NIM_NIL;
				T329_ = (*conf).configFiles->data[T328_]; (*conf).configFiles->data[T328_] = copyStringRC1(configPathX60gensym35_);
				if (T329_) nimGCunrefNoCycle(T329_);
			}
			LA326_: ;
		}
		LA316_: ;
	}
	LA275_: ;
	scriptFile = noschangeFileExt((*conf).projectFull, ((NimStringDesc*) &TM__fOa3jIA3WjH3i5KrG7HeEg_25));
	scriptIsProj = eqeq___nimconf_430(scriptFile, (*conf).projectFull);
	{
		if (!((*conf).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 12))) goto LA332_;
		{
			NimStringDesc** filenameX60gensym36_;
			NI i_2;
			NI L;
			NI T335_;
			filenameX60gensym36_ = (NimStringDesc**)0;
			i_2 = ((NI) 0);
			T335_ = ((*conf).configFiles ? (*conf).configFiles->Sup.len : 0);
			L = T335_;
			{
				while (1) {
					if (!(i_2 < L)) goto LA337;
					filenameX60gensym36_ = (&(*conf).configFiles->data[i_2]);
					liMessage__msgs_1128(conf, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 87), (*filenameX60gensym36_), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__fOa3jIA3WjH3i5KrG7HeEg_26, NIM_FALSE);
					i_2 += ((NI) 1);
				} LA337: ;
			}
		}
		asgnRef((void**) (&(*conf).configFiles), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) setLengthSeqV2(((*conf).configFiles)?&((*conf).configFiles)->Sup:NIM_NIL, (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_), ((NI) 0)));
	}
	LA332_: ;
	{
		if (!!(((8390912 &((NU32)1<<((NU)((*conf).cmd)&31U)))!=0))) goto LA340_;
		{
			NimStringDesc* pX60gensym40_;
			tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* sX60gensym40_;
			if (!((*conf).cmd == ((tyEnum_Command__9bV9cjzU2RVpin7yQI1gAZgg) 12))) goto LA344_;
			pX60gensym40_ = (*conf).projectFull;
			sX60gensym40_ = NIM_NIL;
			{
				NIM_BOOL T348_;
				T348_ = (NIM_BOOL)0;
				T348_ = NIM_TRUE;
				if (!(T348_)) goto LA349_;
				T348_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 2))&63U)))!=0);
				LA349_: ;
				if (!T348_) goto LA350_;
				{
					if (!(*conf).projectIsStdin) goto LA354_;
					sX60gensym40_ = llStreamOpen__llstream_63(__stdinp);
				}
				goto LA352_;
				LA354_: ;
				{
					if (!(*conf).projectIsCmd) goto LA357_;
					sX60gensym40_ = llStreamOpen__llstream_30((*conf).cmdInput);
				}
				goto LA352_;
				LA357_: ;
				LA352_: ;
			}
			LA350_: ;
			{
				NIM_BOOL T361_;
				T361_ = (NIM_BOOL)0;
				T361_ = (sX60gensym40_ == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL));
				if (!(T361_)) goto LA362_;
				T361_ = nosfileExists(pX60gensym40_);
				LA362_: ;
				if (!T361_) goto LA363_;
				sX60gensym40_ = llStreamOpen__llstream_69(pX60gensym40_, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 0));
			}
			LA363_: ;
			{
				NI T369_;
				NimStringDesc* T370_;
				if (!!((sX60gensym40_ == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL)))) goto LA367_;
				asgnRef((void**) (&(*conf).configFiles), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).configFiles), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
				T369_ = (*conf).configFiles->Sup.len++;
				T370_ = NIM_NIL;
				T370_ = (*conf).configFiles->data[T369_]; (*conf).configFiles->data[T369_] = copyStringRC1(pX60gensym40_);
				if (T370_) nimGCunrefNoCycle(T370_);
				runNimScript__scriptconfig_188(cache, pX60gensym40_, idgen, NIM_FALSE, conf, sX60gensym40_);
			}
			LA367_: ;
		}
		goto LA342_;
		LA344_: ;
		{
			NimStringDesc* pX60gensym43_;
			tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* sX60gensym43_;
			pX60gensym43_ = scriptFile;
			sX60gensym43_ = NIM_NIL;
			{
				NIM_BOOL T374_;
				T374_ = (NIM_BOOL)0;
				T374_ = NIM_TRUE;
				if (!(T374_)) goto LA375_;
				T374_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 2))&63U)))!=0);
				LA375_: ;
				if (!T374_) goto LA376_;
				{
					if (!(*conf).projectIsStdin) goto LA380_;
					sX60gensym43_ = llStreamOpen__llstream_63(__stdinp);
				}
				goto LA378_;
				LA380_: ;
				{
					if (!(*conf).projectIsCmd) goto LA383_;
					sX60gensym43_ = llStreamOpen__llstream_30((*conf).cmdInput);
				}
				goto LA378_;
				LA383_: ;
				LA378_: ;
			}
			LA376_: ;
			{
				NIM_BOOL T387_;
				T387_ = (NIM_BOOL)0;
				T387_ = (sX60gensym43_ == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL));
				if (!(T387_)) goto LA388_;
				T387_ = nosfileExists(pX60gensym43_);
				LA388_: ;
				if (!T387_) goto LA389_;
				sX60gensym43_ = llStreamOpen__llstream_69(pX60gensym43_, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 0));
			}
			LA389_: ;
			{
				NI T395_;
				NimStringDesc* T396_;
				if (!!((sX60gensym43_ == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL)))) goto LA393_;
				asgnRef((void**) (&(*conf).configFiles), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).configFiles), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
				T395_ = (*conf).configFiles->Sup.len++;
				T396_ = NIM_NIL;
				T396_ = (*conf).configFiles->data[T395_]; (*conf).configFiles->data[T395_] = copyStringRC1(pX60gensym43_);
				if (T396_) nimGCunrefNoCycle(T396_);
				runNimScript__scriptconfig_188(cache, pX60gensym43_, idgen, NIM_FALSE, conf, sX60gensym43_);
			}
			LA393_: ;
		}
		LA342_: ;
	}
	goto LA338_;
	LA340_: ;
	{
		{
			NimStringDesc* pX60gensym46_;
			tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg* sX60gensym46_;
			if (!!(scriptIsProj)) goto LA400_;
			pX60gensym46_ = scriptFile;
			sX60gensym46_ = NIM_NIL;
			{
				NIM_BOOL T404_;
				T404_ = (NIM_BOOL)0;
				T404_ = NIM_TRUE;
				if (!(T404_)) goto LA405_;
				T404_ = (((*conf).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__WCvlY9b2UxZ4Fz8D59cE3YSg) 2))&63U)))!=0);
				LA405_: ;
				if (!T404_) goto LA406_;
				{
					if (!(*conf).projectIsStdin) goto LA410_;
					sX60gensym46_ = llStreamOpen__llstream_63(__stdinp);
				}
				goto LA408_;
				LA410_: ;
				{
					if (!(*conf).projectIsCmd) goto LA413_;
					sX60gensym46_ = llStreamOpen__llstream_30((*conf).cmdInput);
				}
				goto LA408_;
				LA413_: ;
				LA408_: ;
			}
			LA406_: ;
			{
				NIM_BOOL T417_;
				T417_ = (NIM_BOOL)0;
				T417_ = (sX60gensym46_ == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL));
				if (!(T417_)) goto LA418_;
				T417_ = nosfileExists(pX60gensym46_);
				LA418_: ;
				if (!T417_) goto LA419_;
				sX60gensym46_ = llStreamOpen__llstream_69(pX60gensym46_, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 0));
			}
			LA419_: ;
			{
				NI T425_;
				NimStringDesc* T426_;
				if (!!((sX60gensym46_ == ((tyObject_TLLStream__7Xg7qwR6egjB3ej43ivLqg*) NIM_NIL)))) goto LA423_;
				asgnRef((void**) (&(*conf).configFiles), (tySequence__sM4lkSb7zS6F7OVMvW9cffQ*) incrSeqV3((TGenericSeq*)((*conf).configFiles), (&NTIseqLstringT__sM4lkSb7zS6F7OVMvW9cffQ_)));
				T425_ = (*conf).configFiles->Sup.len++;
				T426_ = NIM_NIL;
				T426_ = (*conf).configFiles->data[T425_]; (*conf).configFiles->data[T425_] = copyStringRC1(pX60gensym46_);
				if (T426_) nimGCunrefNoCycle(T426_);
				runNimScript__scriptconfig_188(cache, pX60gensym46_, idgen, NIM_FALSE, conf, sX60gensym46_);
			}
			LA423_: ;
		}
		goto LA398_;
		LA400_: ;
		{
		}
		LA398_: ;
	}
	LA338_: ;
	{
		NimStringDesc** filenameX60gensym49_;
		NI i_3;
		NI L_2;
		NI T429_;
		filenameX60gensym49_ = (NimStringDesc**)0;
		i_3 = ((NI) 0);
		T429_ = ((*conf).configFiles ? (*conf).configFiles->Sup.len : 0);
		L_2 = T429_;
		{
			while (1) {
				if (!(i_3 < L_2)) goto LA431;
				filenameX60gensym49_ = (&(*conf).configFiles->data[i_3]);
				liMessage__msgs_1128(conf, unknownLineInfo__lineinfos_284, ((tyEnum_TMsgKind__J0cVyqzpFKvufCivtQUgHQ) 87), (*filenameX60gensym49_), ((tyEnum_TErrorHandling__sOC1wCv9bUYRquMih1VRi3w) 1), TM__fOa3jIA3WjH3i5KrG7HeEg_26, NIM_FALSE);
				i_3 += ((NI) 1);
			} LA431: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, atmnimconfdotnim_DatInit000)(void) {
NTIseqLboolT__shxop0zPIs5Ec3k71aCLuQ_.size = sizeof(tySequence__shxop0zPIs5Ec3k71aCLuQ*);
NTIseqLboolT__shxop0zPIs5Ec3k71aCLuQ_.align = NIM_ALIGNOF(tySequence__shxop0zPIs5Ec3k71aCLuQ*);
NTIseqLboolT__shxop0zPIs5Ec3k71aCLuQ_.kind = 24;
NTIseqLboolT__shxop0zPIs5Ec3k71aCLuQ_.base = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
NTIseqLboolT__shxop0zPIs5Ec3k71aCLuQ_.flags = 2;
NTIseqLboolT__shxop0zPIs5Ec3k71aCLuQ_.marker = Marker_tySequence__shxop0zPIs5Ec3k71aCLuQ;
}

